/* This file is part of kmobiletools.
   See COPYING file for licensing information.

   (C) 2005 Marco Gulino <marco.gulino@gmail.com>
   (C) 2005 Stefan Bogner <bochi@kmobiletools.org>

*/

#include "kmobiletoolsgammu_engine.h"
#include "gammu_jobs.h"
#include "memory_jobs.h"
#include "sms_jobs.h"
#include <kmessagebox.h>
#include <klocale.h>
#include <qtimer.h>

#include "device.h"
#include <qstringlist.h>
#include <qdatetime.h>
#include <kabc/vcardconverter.h>

#include "contactptrlist.h"

#include <kdebug.h>
using namespace KMobileTools;

kmobiletoolsGammu_engine::kmobiletoolsGammu_engine(QObject *parent, const char *name)
 : kmobiletoolsEngine(parent, name)
{
    kdDebug() << "Initialized Gammu engine" << endl;
    dev = new Device( this->name() );
    connect( dev, SIGNAL( connected() ), SIGNAL( connected() ) );
    connect( dev, SIGNAL( connected() ), this, SLOT( devConnected() ) );
}

kmobiletoolsGammu_engine::~kmobiletoolsGammu_engine()
{
}

extern "C"
{
    void* init_libkmobiletools_gammu()
    {
      return new kmobiletoolsGammu_engineFactory;
    }
};

kmobiletoolsGammu_engineFactory::kmobiletoolsGammu_engineFactory()
{
}

kmobiletoolsGammu_engineFactory::~kmobiletoolsGammu_engineFactory()
{
}

kmobiletoolsGammu_engine *kmobiletoolsGammu_engineFactory::createObject(QObject *parent, const char *name,
                                            const char *classname, const QStringList &args )
{
    (void) classname;
    (void) args;
    return new kmobiletoolsGammu_engine(parent, name);
}


#include "kmobiletoolsgammu_engine.moc"


void kmobiletoolsGammu_engine::getPhoneInfos()
{
    enqueueJob( new FetchPhoneInfos(dev, this, this->name() ) );
}

void kmobiletoolsGammu_engine::getSMSFolders()
{
    //enqueueJob( new GetSMSFolders(dev, this, this->name() ) );
}

using namespace ThreadWeaver;
void kmobiletoolsGammu_engine::processSlot(Job* p_job)
{
    kmobiletoolsJob *job=(kmobiletoolsJob *) p_job;
    kdDebug() << "processSlot() with job==" << job->type() << endl;
    
    switch( job->type() ){

        case kmobiletoolsJob::fetchPhoneInfos:
            s_manufacturer=( (FetchPhoneInfos*) job )->manufacturer();
            if( s_manufacturer.contains( "Nokia", false ) ) i_manufacturer = Nokia;
            s_model=( (FetchPhoneInfos*) job )->model();
            s_revision=( (FetchPhoneInfos*) job )->revision();
            s_imei=( (FetchPhoneInfos*) job )->imei();
        break;

        case kmobiletoolsJob::pollStatus:
            emit charge( ( (PollStatus*) job )->phoneCharge() );
            emit signal( ( (PollStatus*) job )->phoneSignal() );
            emit networkName( ( (PollStatus*) job )->networkName() );
            emit isRinging(  ( (PollStatus*) job )->ringing() );
            if( ( (PollStatus*) job )->unreadSMS() != s_newSMS || ( (PollStatus*) job )->totalSMS() != s_totalSMS ) 
            {
                s_newSMS=( ( (PollStatus*) job )->unreadSMS() );
                s_totalSMS = ( ( (PollStatus*) job )->totalSMS() );
                emit updateInfoPage(0);
            }
        break;

        case kmobiletoolsJob::fetchAddressBook:
            freeMemEntries.clear();
            //addresseeList&=&((FetchMemory*) job )->addresseeList;
            freeMemEntries.append( ((FetchMemory*) job )->freeEntries.first() );
            emit phoneBookUpdated();
        break;

        case kmobiletoolsJob::fetchSMS:
            p_smsList =&((FetchSMS*) job)->smsList;
            emit smsListUpdated();
        break;

        case kmobiletoolsJob::smsFolders:
            s_folders = (((GetSMSFolders*) job)->smsFolders) ;
            emit addSMSFolders();
        break;
    }
}

void kmobiletoolsGammu_engine::pollPhoneStatus()
{
    enqueueJob( new PollStatus(dev, this, this->name() ) );
}

void kmobiletoolsGammu_engine::initPhone()
{
    dev->initPhone();
    getPhoneInfos();
}

int kmobiletoolsGammu_engine::getFreeEntry( GSM_MemoryType t )
{
    QValueList<GSM_MemoryEntry>::iterator it;
    for ( it = freeMemEntries.begin(); it != freeMemEntries.end(); ++it )
    {
        if( (*it).MemoryType == t ) 
        {
            return (*it).Location;
            break;
        }
    }
}

void kmobiletoolsGammu_engine::devConnected()
{
    pollPhoneStatus();
}

void kmobiletoolsGammu_engine::retrieveAddressBook()
{
    //enqueueJob( new FetchMemory( dev, this, this->name() ) );
}

void kmobiletoolsGammu_engine::retrieveSMSList()
{
    //getSMSFolders();
    //enqueueJob( new FetchSMS( dev, this, this->name() ) );
}

void kmobiletoolsGammu_engine::slotAddAddressee( QValueList<KABC::Addressee>* list )
{
    //enqueueJob( new EditPbk( list, dev, false, this, this->name() ) );
    //enqueueJob( new FetchMemory( dev, this, this->name() ) );
}

void kmobiletoolsGammu_engine::slotDelAddressee( QValueList<KABC::Addressee>* list )
{
    //enqueueJob( new EditPbk( list, dev, true, this, this->name() ) );
    //enqueueJob( new FetchMemory( dev, this, this->name() ) );
}

int kmobiletoolsGammu_engine::availPbSlots()
{
    /// @todo implement me
}

void kmobiletoolsGammu_engine::slotEditAddressee(KABC::Addressee* oldAddressee, KABC::Addressee* newAddressee)
{
    //enqueueJob( new EditPbk( oldAddressee, newAddressee, dev, this, this->name() ) );
}
