// This file is part of kmobiletools
// Thanks to Igor Palkin (ip821) for the code.


#include <gammu/gammu.h>

#include "qphoneerror.h"

typedef struct
{
    int		ErrorNum;
    QString	ErrorText;
}
PrintErrorEntry;

PrintErrorEntry PrintErrorEntries[] = {
                                          {ERR_NONE,			"No error."},
                                          {ERR_DEVICEOPENERROR,		"Error opening device. Unknown/busy or no permissions."},
                                          {ERR_DEVICELOCKED,		"Error opening device. Device locked."},
                                          {ERR_DEVICENOTEXIST,		"Error opening device. Not exist."},
                                          {ERR_DEVICEBUSY,		"Error opening device. Already opened by other application."},
                                          {ERR_DEVICENOPERMISSION,	"Error opening device. No permissions."},
                                          {ERR_DEVICENODRIVER,		"Error opening device. No required driver in operating system."},
                                          {ERR_DEVICENOTWORK,		"Error opening device. Some hardware not connected/wrong configured."},
                                          {ERR_DEVICEDTRRTSERROR,		"Error setting device DTR or RTS."},
                                          {ERR_DEVICECHANGESPEEDERROR,	"Error setting device speed. Maybe speed not supported."},
                                          {ERR_DEVICEWRITEERROR,		"Error writing device."},
                                          {ERR_DEVICEREADERROR,		"Error during reading device"},
                                          {ERR_DEVICEPARITYERROR,		"Can't set parity on device"},
                                          {ERR_TIMEOUT,			"No response in specified timeout. Probably phone not connected."},
                                          /* Some missed */
                                          {ERR_UNKNOWNRESPONSE,		"Unknown response from phone. See readme.txt, how to report it."},
                                          /* Some missed */
                                          {ERR_UNKNOWNCONNECTIONTYPESTRING,"Unknown connection type string. Check config file."},
                                          {ERR_UNKNOWNMODELSTRING,	"Unknown model type string. Check config file."},
                                          {ERR_SOURCENOTAVAILABLE,	"Some required functions not compiled for your OS. Please contact."},
                                          {ERR_NOTSUPPORTED,		"Function not supported by phone."},
                                          {ERR_EMPTY,			"Entry is empty"},
                                          {ERR_SECURITYERROR,		"Security error. Maybe no PIN ?"},
                                          {ERR_INVALIDLOCATION,		"Invalid location. Maybe too high ?"},
                                          {ERR_NOTIMPLEMENTED,		"Function not implemented. Help required."},
                                          {ERR_FULL,			"Memory full."},
                                          {ERR_UNKNOWN,			"Unknown error."},
                                          /* Some missed */
                                          {ERR_CANTOPENFILE,		"Can't open specified file. Read only ?"},
                                          {ERR_MOREMEMORY,		"More memory required..."},
                                          {ERR_PERMISSION,		"Permission to file/device required..."},
                                          {ERR_EMPTYSMSC,			"Empty SMSC number. Set in phone or use -smscnumber"},
                                          {ERR_INSIDEPHONEMENU,		"You're inside phone menu (during editing ?). Leave it and try again."},
                                          {ERR_WORKINPROGRESS,		"Function is during writing. If want help, please contact with authors."},
                                          {ERR_PHONEOFF,			"Phone is disabled and connected to charger"},
                                          {ERR_FILENOTSUPPORTED,		"File format not supported by Gammu"},
                                          {ERR_BUG,			"Nobody is perfect, some bug appeared in protocol implementation. Please contact authors."},
                                          {ERR_CANCELED,			"Transfer was canceled by phone (you pressed cancel on phone?)."},
                                          /* Some missed */
                                          {ERR_OTHERCONNECTIONREQUIRED,	"Current connection type doesn't support called function."},
                                          {ERR_WRONGCRC,			"CRC error."},
                                          {ERR_INVALIDDATETIME,		"Invalid date or time specified."},
                                          {ERR_MEMORY,			"Phone memory error, maybe it is read only"},
                                          {ERR_INVALIDDATA,		"Invalid data"},
                                          {ERR_FILEALREADYEXIST,		"File with specified name already exist"},

                                          {0,				""}
                                      };

QPhoneError::QPhoneError()
{}


QPhoneError::~QPhoneError()
{}

QString QPhoneError::getErrorMsg(int e)
{
    int i=0;
    QString msg;

    while (PrintErrorEntries[i].ErrorNum != 0)
    {
        if (PrintErrorEntries[i].ErrorNum == e)
        {
            msg	= PrintErrorEntries[i].ErrorText;
            break;
        }
        i++;
    }
    return msg;
}
