/* This file is part of kmobiletools.
   See COPYING file for licensing information.

   (C) 2005 Marco Gulino <marco.gulino@gmail.com>
   (C) 2005 Stefan Bogner <bochi@kmobiletools.org>

*/

#include "sms_jobs.h"
#include "qphoneerror.h"

#include "qregexp.h"
#include <unistd.h>
#include <qstringlist.h>
#include <qdatetime.h>
#include "kmobiletoolsgammu_engine.h"
#include <kdebug.h>

FetchSMS::FetchSMS(Device *dev, kmobiletoolsGammu_engine* parent, const char* name) : kmobiletoolsGammuJob(dev, parent, name){}

void FetchSMS::run()
{
    kdDebug() << "[ !!! ] Fetching all SMS" << endl;
    GSM_MultiSMSMessage sms;
    GSM_SMSFolders folders;
    bool start = true;
    error=p_device->phone->GetSMSFolders(&p_device->s, &folders);
    kdDebug() << "[ !!! ] GetSMSFolders: " << err.getErrorMsg(error) << endl;
    QDate d;
    QTime t;
    
    while (error == ERR_NONE) 
    {
        sms.SMS[0].Folder=0x00;

        error=p_device->phone->GetNextSMS(&p_device->s, &sms, start);
        kdDebug() << "[ !!! ] GetNextSMS: " << err.getErrorMsg(error) << endl;
        
        switch (error) {

            case ERR_EMPTY:
            break;

            default:

                SMS *tmp = new SMS;

                tmp->setId( sms.SMS[0].Location );

                switch(sms.SMS[0].Memory) {

                    case MEM_SM:
                    break;

                    case MEM_ME:
                    break;
                }

                tmp->setText( (char*)DecodeUnicodeConsole(sms.SMS[0].Text));
                tmp->setNumbers( (char*)DecodeUnicodeConsole(sms.SMS[0].Number));
                d.setYMD(sms.SMS[0].DateTime.Year,sms.SMS[0].DateTime.Month,sms.SMS[0].DateTime.Day);
                t.setHMS(sms.SMS[0].DateTime.Hour,sms.SMS[0].DateTime.Minute,sms.SMS[0].DateTime.Second);
                tmp->setDateTime( QDateTime( d, t ) );
                tmp->setFolder( sms.SMS[0].Folder );
                smsList.append( tmp );
        }

        start=false;
    }
}

GetSMSFolders::GetSMSFolders(Device *dev, kmobiletoolsGammu_engine* parent, const char* name) : kmobiletoolsGammuJob(dev, parent, name){}

void GetSMSFolders::run()
{
    GSM_SMSFolders f;

    error=p_device->phone->GetSMSFolders(&p_device->s, &f);
    kdDebug() << "[ !!! ] GetSMSFolders: " << err.getErrorMsg(error) << ", " << f.Number << " Folders." << endl;

    for (int i=0;i<f.Number;i++) 
    {
        smsFolders.append( QString::fromUtf8( (const char*) DecodeUnicodeConsole( (unsigned char*) f.Folder[i].Name ) ) );
    }
}